@@ -675,6 +675,13 @@ module OCaml_501 = struct
   let string_version = "5.1"
 end
 let ocaml_501 : OCaml_501.types ocaml_version = (module OCaml_501)
+module OCaml_502 = struct
+  module Ast = Astlib.Ast_502
+  include Make_witness(Astlib.Ast_502)
+  let version = 502
+  let string_version = "5.2"
+end
+let ocaml_502 : OCaml_502.types ocaml_version = (module OCaml_502)
 (*$*)
 
 let all_versions : (module OCaml_version) list = [
@@ -695,6 +702,7 @@ let all_versions : (module OCaml_version) list = [
 (module OCaml_414 : OCaml_version);
 (module OCaml_500 : OCaml_version);
 (module OCaml_501 : OCaml_version);
+(module OCaml_502 : OCaml_version);
 (*$*)
 ]
 
@@ -731,6 +739,8 @@ include Register_migration(OCaml_414)(OCaml_500)
     (Astlib.Migrate_414_500)(Astlib.Migrate_500_414)
 include Register_migration(OCaml_500)(OCaml_501)
     (Astlib.Migrate_500_501)(Astlib.Migrate_501_500)
+include Register_migration(OCaml_501)(OCaml_502)
+    (Astlib.Migrate_501_502)(Astlib.Migrate_502_501)
 (*$*)
 
 module OCaml_current = OCaml_OCAML_VERSION
